@@ -13,6 +13,7 @@ ALERTS_TABLE = 'alerts.items'
 ALERTS_CONFIGS_TABLE = 'alerts.config'
 METRICS_TIMESERIES_TABLE = 'metrics.details'
 LOGS_METRICS_FETCHING_TABLE = 'logs.cloud_metric_fetching'
+COMPONENTS_TABLE = 'component.info'
 
 ############ ALERTS ###########################
 def insert_alert(alert_id, metric_id, org_id, app_id, team_id, assigned_to, start_time,
@@ -52,7 +53,7 @@ def get_alert_item_by_key(anom_id, dynamodb):
   alert_item = get_item(key_dict, ALERTS_TABLE, dynamodb)
   return alert_item
 
-def update_alert_with_related_anomalies(alert_id,start_time, corr_anoms_dict, related_prev_anomalies, dynamodb):
+def update_alert_with_related_anomalies(alert_id, start_time, corr_anoms_dict, related_prev_anomalies, dynamodb):
   #https://stackoverflow.com/questions/52367094/how-to-update-dynamodb-table-with-dict-data-type-boto3
   #TODO add similar alerts
   update_expression = "set anomalies_dict=:a, related_prev_anomalies=:r"
@@ -69,7 +70,7 @@ def update_alert_with_related_anomalies(alert_id,start_time, corr_anoms_dict, re
 
   return True
 
-def terminate_alert(alert_id,start_time, end_timestamp, dynamodb):
+def terminate_alert(alert_id, start_time, end_timestamp, dynamodb):
   update_expression = "set end_timestamp=:e"
   expression_attr_values = {
     ':e': end_timestamp
@@ -126,6 +127,7 @@ def chunks(lst, n):
     for i in range(0, len(lst), n):
         yield lst[i:i + n]
 
+#deprecated
 def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
   #convert list of metric objects into list of metric dicts
 
@@ -144,11 +146,6 @@ def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
 
 def batch_insert_metric_details_objects(list_of_metric_objects, dynamodb):
   #convert list of metric objects into list of metric dicts
-
-  #print('Size of {}:'.format(metric_object.get_metric_name()))
-  #print(sys.getsizeof(json.dumps(metric_object.to_dict())))
-  date = datetime.today()
-  date = str(date).split(' ')[0]
   batch_insert_list = chunks(list_of_metric_objects, 25)
   for chunk_list in batch_insert_list:
     metric_list = []
@@ -188,6 +185,17 @@ def scan_metrics_by_encrypted_id(anom_alarm_id, dynamodb):
   metric_item = metric_list[0]
   return metric_item
 
+############## COMPONENTS ###################
+def batch_insert_component_info_objects(list_of_component_objects, dynamodb):
+  # convert list of metric objects into list of metric dicts
+  batch_insert_list = chunks(list_of_component_objects, 25)
+  for chunk_list in batch_insert_list:
+    component_list = []
+    for component_obj in chunk_list:
+      curr_component = component_obj.to_dict()
+      #decide which are going to be the key attrs
+      component_list.append(curr_component)
+    batch_insert(component_list, COMPONENTS_TABLE, dynamodb)
 
 ############## ALERT CONFIGS ################
 def query_alerts_configs_by_key(metric_id, dynamodb):
